/**
 * @file patch_search.h
 * This file contains all the functions for the patch search procedure that computes the distance of 
 * a patch to all input patches and then randomly pick on of the patches that are close to the minimal distance.
 *
 * @author Lara Raad, Bruno Galerne
 * @date   2014/06/11
 */


#ifndef  PATCH_SEARCH_H_
#define  PATCH_SEARCH_H_

#include "common.h"
#include "mt.h"
#include "quilting_lib.h"

void compute_input_patch_norms(Image src_im, 
                               long double *patch_normsH, long double *patch_normsV, long double *patch_normsL, 
                               int patch_sz, int overlap_sz);

static void pick_patch(Image_LD *distances, int h_dict, int w_dict, Corner *patch, float tol, unsigned int *seed);

void patch_search(Image src_im, Image out_im, Corner temp, int patch_sz, 
                  long double *src_patch_normsH, long double *src_patch_normsV, long double *src_patch_normsL, 
                  fftwl_complex *fft_srcR,fftwl_complex *fft_srcG, fftwl_complex *fft_srcB, 
                  int h_dict, int w_dict, Corner *patch, float tol, unsigned int *seed);

#endif

